@@ -5,8 +5,8 @@
 ;; Author: Yuwei Tian <fishtai0@gmail.com>, Daniel Mendler <mail@daniel-mendler.de>
 ;; Maintainer: Daniel Mendler <mail@daniel-mendler.de>
 ;; Created: 2022
-;; Version: 2.3
-;; Package-Requires: ((emacs "29.1") (compat "30") (corfu "2.3"))
+;; Version: 2.5
+;; Package-Requires: ((emacs "29.1") (compat "30") (corfu "2.5"))
 ;; URL: https://github.com/minad/corfu
 
 ;; This file is part of GNU Emacs.
@@ -293,7 +293,9 @@ form (X Y WIDTH HEIGHT DIR)."
   (pcase-let*
       ((cw (default-font-width))
        (lh (default-line-height))
-       (border (alist-get 'internal-border-width corfu--frame-parameters))
+       (border (if (display-graphic-p corfu--frame)
+                   (alist-get 'internal-border-width corfu--frame-parameters)
+                 0))
        (`(,_pfx ,_pfy ,pfw ,pfh)
         (corfu-popupinfo--frame-geometry (frame-parent corfu--frame)))
        (`(,cfx ,cfy ,cfw ,cfh) (corfu-popupinfo--frame-geometry corfu--frame))
@@ -363,7 +365,9 @@ form (X Y WIDTH HEIGHT DIR)."
           (corfu-popupinfo--hide)
           (setq cand-changed nil coords-changed nil)))
       (when (or cand-changed coords-changed)
-        (pcase-let* ((border (alist-get 'internal-border-width corfu--frame-parameters))
+        (pcase-let* ((border (if (display-graphic-p corfu--frame)
+                                 (alist-get 'internal-border-width corfu--frame-parameters)
+                               0))
                      (`(,area-x ,area-y ,area-w ,area-h ,area-d)
                       (corfu-popupinfo--area
                        (if cand-changed
